@@ -11,6 +11,7 @@ from interpret.glassbox import ExplainableBoostingClassifier, ExplainableBoostin
 
 
 onnx_type_for={
+    'bool': onnx.TensorProto.BOOL,
     'float': onnx.TensorProto.FLOAT,
     'double': onnx.TensorProto.DOUBLE,
     'int': onnx.TensorProto.INT64,
@@ -25,6 +26,41 @@ def infer_features_dtype(dtype, feature_name):
 
     return feature_dtype
 
+
+def get_dtype_from_pandas(df):
+    """Infers the features names and types from a pandas dataframe
+
+    Example:
+        >>>import ebm2onnx
+        >>>
+        >>>dtype = ebm2onnx.get_dtype_from_pandas(my_df)
+    Args:
+        df: A pandas dataframe
+
+    Returns:
+        A dict that can be used as the type argument of the to_onnx function.
+    """
+    dtype = {}
+    df_types = df.dtypes.values
+    for i, k in enumerate(df.dtypes.index):
+        if df_types[i] == np.float32:
+            dtype[k] = 'float'
+        elif df_types[i] == np.double:
+            dtype[k] = 'double'
+        elif df_types[i] == int:
+            dtype[k] = 'int'
+        elif df_types[i] == bool:
+            dtype[k] = 'bool'
+        elif df_types[i] == str:
+            dtype[k] = 'str'
+        elif df_types[i] == object:
+            dtype[k] = 'str'
+        else:
+            raise ValueError("column {} is of type {} that is not supported".format(k, df_types[i]))
+
+    return dtype
+
+
 def to_onnx(model, dtype, name="ebm",
             predict_proba=False,
             explain=False,
@@ -72,7 +108,10 @@ def to_onnx(model, dtype, name="ebm",
             col_mapping = model.preprocessor_.col_mapping_[feature_group[0]]
             additive_terms = model.additive_terms_[feature_index]
 
-            part = graph.create_input(root, feature_name, onnx.TensorProto.STRING, [None])
+            feature_dtype = infer_features_dtype(dtype, feature_name)
+            part = graph.create_input(root, feature_name, feature_dtype, [None])
+            if feature_dtype != onnx.TensorProto.STRING:
+                part = ops.cast(onnx.TensorProto.STRING)(part)
             part = ops.flatten()(part)
             inputs[feature_index] = part
             part = ebm.get_bin_index_on_categorical_value(col_mapping)(part)
